.. title:: Table of Contents

Welcome to the documentation of **pypoman**, a PYthon module for POlyhedral
MANipulations.

.. toctree::
    :maxdepth: 1

    chebyshev-center.rst
    duality.rst
    intersection.rst
    polygon.rst
    projection.rst
    references.rst
